# pytensils
`pytensils` is a Python package that provides general utility functions for managing configuration, directories and data-types as well as a basic run-time
profiler.

# Installation
The source code is available on [GitHub](https://github.com/thomaseleff/pytensils).

```
# Via PyPI
pip install pytensils
```
